import { Component, OnInit } from '@angular/core';
import { ActivatedRoute, Router } from '@angular/router';
import { Boilerplate } from 'src/app/models/boilerplate.model';
import { BoilerplateService } from 'src/app/services/boilerplate.service';

@Component({
  selector: 'app-boilerplate-details',
  templateUrl: './boilerplate-details.component.html',
  styleUrls: ['./boilerplate-details.component.scss']
})
export class BoilerplateDetailsComponent implements OnInit {

  currentboilerplate: Boilerplate = {
    has_prefix: false,
    has_main: false,
    has_suffix: false
  };
  message = '';

  constructor(
    private boilerplateService: BoilerplateService,
    private route: ActivatedRoute,
    private router: Router) { }

  ngOnInit(): void {
    this.message = '';
    this.getBoilerplate(this.route.snapshot.params.id);
  }

  getBoilerplate(id: string): void {
    this.boilerplateService.get(id)
      .subscribe(
        data => {
          this.currentboilerplate = data;
          console.log(data);
        },
        error => {
          console.log(error);
        });
  }

  updateBoilerplate(): void {
    this.boilerplateService.update(this.currentboilerplate.id, this.currentboilerplate)
      .subscribe(
        response => {
          console.log(response);
          this.message = response.message;
        },
        error => {
          console.log(error);
        });
  }

  deleteBoilerplate(): void {
    this.boilerplateService.delete(this.currentboilerplate.id)
      .subscribe(
        response => {
          console.log(response);
          this.router.navigate(['/boilerplates']);
        },
        error => {
          console.log(error);
        });
  }

}
